@@ -551,18 +551,17 @@ def mountEcryptfs(userName, userPwd, userDir):
     return mountProcess.success()
 
 
-def isBootstrapDataOnly(directory):
+def isBootstrapDataOnly(user_dir):
     """
     Каталог содержит только сертификат, созданный командой cl-core
-    а так же настроенные симлинки на .face
+    а так же настроенные симлинки на .face, skel
     """
-    userCalculate = path.join(directory, ".calculate")
-    return (set(listDirectory(directory)) <= {
-        ".calculate",
-        ".face",
-        ".dmrc",
-        ".face.icon"} and
-            set(listDirectory(userCalculate)) == {"client_cert"})
+    from calculate.lib.utils.files import find
+    skel_files = set([x for x in find('/etc/skel', fullpath=False)
+                  if not x.startswith(".calculate")])
+    user_files = set([x for x in find(user_dir, fullpath=False)
+                  if not x.startswith(".calculate")])
+    return not len(user_files - skel_files) > 10
 
 
 def getPortageUidGid():
